# AttParser

AttParser parses a string like you might find in an HTML tag. Optionally, it will
convert certain values into other classes like Integer or TrueClass.

In its simplest use, give AttParser a string that is formatted like the
attributes in HTML. Then run the string through `AttParser.parse()`. That method
will return a hash.

```ruby 
raw = 'whatever="dude" ready YEAH=man'
atts = AttParser.parse(raw)
atts['whatever'] # => "dude"
atts['ready']    # => nil
atts['yeah']     # => "man"
```

The attribute names are downcased. Values quotes are returned as string. Values
without spaces are returned as string. If an attribute does not have a value
(i.e. there is no equals sign) then the value is `nil`.

## Infer

If you add the `infer` option then certain values are inferred as objects other
than strings. NOTE: Only unquoted strings are inferred, never quoted strings.
Quoted strings are always returned as strings.

```ruby 
raw = 'my-false=false my-true=true my-int=-2 my-float=3.4 my-nil=nil'
atts = AttParser.parse(raw, 'infer'=>true)
atts['my-false'].class  # => FalseClass
atts['my-true'].class   # => TrueClass
atts['my-int'].class    # => Integer
atts['my-float'].class  # => Float
atts['my-nil'].class    # => NilClass
```

## That's it

That's what AttParser does. If you want to get more complex, it's probably best
to use JSON.

## Install

```
gem install attparser
```

## Author

Mike O'Sullivan
mike@idocs.com

## History

| version | date          | notes                                                 |
|---------|---------------|-------------------------------------------------------|
| 1.0     | June 18, 2020 | Initial upload.                                       |